# v0.0.95 (2021-10-10)

Add feature #8

# v0.0.93-94 (2021-09-02)

Fix issue #5

# v0.0.92 (2021-06-23)

ALL functions of usual way implemented and documented

# v0.0.89 (2021-06-21)

Automatic documentation fix

# v0.0.85 (2021-06-21)

All documentation online

# v0.0.8

Refactoring the whole driver

ASYNC still not implemented

# v0.0.6 (2021-06-16)

### Features

- Asyncio support play
- Record default 5 seconds and more selected.

### Issues

- Record async not working


# v0.0.2 (2021-06-15)

### Features

- Player implemented
